==> openshift-model-machineconfig-6.9.0-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/NetworkInfoFluent.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import io.fabric8.openshift.api.model.config.v1.MTUMigration;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class NetworkInfoFluent<A extends NetworkInfoFluent<A>> extends BaseFluent<A>{
  public NetworkInfoFluent() {
  }
  
  public NetworkInfoFluent(NetworkInfo instance) {
    this.copyInstance(instance);
  }
  private MTUMigration mtuMigration;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(NetworkInfo instance) {
    instance = (instance != null ? instance : new NetworkInfo());
  
    if (instance != null) {
        this.withMtuMigration(instance.getMtuMigration());
        this.withMtuMigration(instance.getMtuMigration());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public MTUMigration getMtuMigration() {
    return this.mtuMigration;
  }
  
  public A withMtuMigration(MTUMigration mtuMigration) {
    this.mtuMigration=mtuMigration; return (A) this;
  }
  
  public boolean hasMtuMigration() {
    return this.mtuMigration != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NetworkInfoFluent that = (NetworkInfoFluent) o;
    if (!java.util.Objects.equals(mtuMigration, that.mtuMigration)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(mtuMigration,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (mtuMigration != null) { sb.append("mtuMigration:"); sb.append(mtuMigration + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> openshift-model-machineconfig-6.9.1-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/NetworkInfoFluent.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import io.fabric8.openshift.api.model.config.v1.MTUMigration;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class NetworkInfoFluent<A extends NetworkInfoFluent<A>> extends BaseFluent<A>{
  public NetworkInfoFluent() {
  }
  
  public NetworkInfoFluent(NetworkInfo instance) {
    this.copyInstance(instance);
  }
  private MTUMigration mtuMigration;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(NetworkInfo instance) {
    instance = (instance != null ? instance : new NetworkInfo());
    if (instance != null) {
          this.withMtuMigration(instance.getMtuMigration());
          this.withMtuMigration(instance.getMtuMigration());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public MTUMigration getMtuMigration() {
    return this.mtuMigration;
  }
  
  public A withMtuMigration(MTUMigration mtuMigration) {
    this.mtuMigration = mtuMigration;
    return (A) this;
  }
  
  public boolean hasMtuMigration() {
    return this.mtuMigration != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NetworkInfoFluent that = (NetworkInfoFluent) o;
    if (!java.util.Objects.equals(mtuMigration, that.mtuMigration)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(mtuMigration,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (mtuMigration != null) { sb.append("mtuMigration:"); sb.append(mtuMigration + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
